/*!
 * Copyright (C) 2005 by egnite Software GmbH. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the copyright holders nor the names of
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY EGNITE SOFTWARE GMBH AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL EGNITE
 * SOFTWARE GMBH OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * For additional information see http://jtagomat.sourceforge.net/
 */

/*!
 * \file led.c
 * \brief Turtelizer LED routine.
 *
 * \verbatim
 *
 * $Log: led.c,v $
 * Revision 1.1  2006/01/09 09:17:40  haraldkipp
 * First check-in.
 *
 *
 * \endverbatim
 */

#include <avr/io.h>

#ifndef LED_CBIT
/*! \brief Port bit of the LED cathode. */
#define LED_CBIT    2
#endif

#ifndef LED_ABIT
/*! \brief Port bit of the LED anode. */
#define LED_ABIT    1
#endif

#ifndef LED_PORT
/*! \brief Port used for LED output. */
#define LED_PORT    PORTB
#endif

#ifndef LED_DDR
/*! \brief Data direction register of the LED output. */
#define LED_DDR     DDRB
#endif

/*!
 * \brief Switch Turtelizer LED on or off.
 *
 * \param on If zero, the LED will be switched off. Otherwise it is switched on.
 */
void Led(unsigned char on)
{
    unsigned char val;

    /*
     * Set the data direction of the LED cathode and anode pin.
     */
    val = LED_DDR;
    val |= _BV(LED_CBIT) | _BV(LED_ABIT);
    LED_DDR = val;

    val = LED_PORT;
    if (on) {
        val &= ~_BV(LED_CBIT);
        val |= _BV(LED_ABIT);
    } else {
        val &= ~_BV(LED_ABIT);
        val |= _BV(LED_CBIT);
    }
    LED_PORT = val;
}
