/*
 * Copyright (C) 2005 by egnite Software GmbH
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * For additional information see http://jtagomat.sourceforge.net/
 */

#include "host.h"

#define P14_RX_READY    1
#define P14_TX_BUSY     2

static inline unsigned long GetP14Control(void)
{
    register unsigned long _val_;
    __asm__ __volatile__("mrc     p14, 0, %0, c0, c0" : "=r" (_val_));
    return _val_;
}

static inline unsigned long GetP14Data(void)
{
    register unsigned long _val_;
    __asm__ __volatile__("mrc     p14, 0, %0, c1, c0" : "=r" (_val_));
    return _val_;
}

static inline void PutP14Data(unsigned long _val_)
{
    __asm__ __volatile__("mcr     p14, 0, %0, c1, c0" : : "r" (_val_));
}

void HostInit(void)
{
}

unsigned long HostRead(void)
{
    while ((GetP14Control() & P14_RX_READY) == 0);
    return GetP14Data();
}

void HostWrite(unsigned long val)
{
    while (GetP14Control() & P14_TX_BUSY);
    PutP14Data(val);
}

unsigned long HostGet(void)
{
    if (GetP14Control() & P14_RX_READY) {
        return GetP14Data();
    }
    return 0;
}

void HostPut(unsigned long val)
{
    if ((GetP14Control() & P14_TX_BUSY) == 0) {
        PutP14Data(val);
    }
}
